<?php
/**
 * Handle a Paypal currency
 *
 * This work is licensed under the MIT License
 * Copyright (c) 2012 Bairwell Ltd
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * PHP Version 5
 *
 * @package Bairwell
 * @subpackage Paypal\Reconciliation
 * @author Richard Bairwell
 * @copyright 2012 Bairwell Ltd - http://www.bairwell.com
 * @license MIT
 */
namespace Bairwell\Paypal\Reconciliation;

/**
 * Handle a Paypal Currency conversion
 */
class Currency
{
    /**
     * Foreign currency
     * @var string
     */
    private $originalCurrency;
    /**
     * Foreign currency amount
     * @var float
     */
    private $originalAmount;
    /**
     * Original foreign currency id
     * @var string
     */
    private $originalTransactionId;
    /**
     * Base currency
     * @var string
     */
    private $baseCurrency;
    /**
     * Base currency amount
     * @var float
     */
    private $baseAmount;
    /**
     * Base transaction id
     * @var string
     */
    private $baseTransactionId;

    /**
     * Sets baseBalance in a fluent manner
     *
     * @param float $baseBalance
     *
     * @return Currency
     */
    public function set_baseBalance($baseBalance)
    {
        $this->baseBalance = $baseBalance;
        return $this;
    }

    /**
     * @return float
     */
    public function get_baseBalance()
    {
        return $this->baseBalance;
    }

    /**
     * Base balance amount
     * @var float
     */
    private $baseBalance;

    /**
     *
     */
    public function __construct()
    {
        $this->baseAmount = NULL;
    }

    /**
     * Sets baseAmount in a fluent manner
     *
     * @param float $baseAmount
     *
     * @return Currency
     */
    public function set_baseAmount($baseAmount)
    {
        $this->baseAmount = $baseAmount;
        return $this;
    }

    /**
     * @return float
     */
    public function get_baseAmount()
    {
        return $this->baseAmount;
    }

    /**
     * Sets baseCurrency in a fluent manner
     *
     * @param string $baseCurrency
     *
     * @return Currency
     */
    public function set_baseCurrency($baseCurrency)
    {
        $this->baseCurrency = $baseCurrency;
        return $this;
    }

    /**
     * @return string
     */
    public function get_baseCurrency()
    {
        return $this->baseCurrency;
    }

    /**
     * Sets baseTransactionId in a fluent manner
     *
     * @param string $baseTransactionId
     *
     * @return Currency
     */
    public function set_baseTransactionId($baseTransactionId)
    {
        $this->baseTransactionId = $baseTransactionId;
        return $this;
    }

    /**
     * @return string
     */
    public function get_baseTransactionId()
    {
        return $this->baseTransactionId;
    }

    /**
     * Sets originalAmount in a fluent manner
     *
     * @param float $originalAmount
     *
     * @return Currency
     */
    public function set_originalAmount($originalAmount)
    {
        $this->originalAmount = $originalAmount;
        return $this;
    }

    /**
     * @return float
     */
    public function get_originalAmount()
    {
        return $this->originalAmount;
    }

    /**
     * Sets originalCurrency in a fluent manner
     *
     * @param string $originalCurrency
     *
     * @return Currency
     */
    public function set_originalCurrency($originalCurrency)
    {
        $this->originalCurrency = $originalCurrency;
        return $this;
    }

    /**
     * @return string
     */
    public function get_originalCurrency()
    {
        return $this->originalCurrency;
    }

    /**
     * Sets originalTransactionId in a fluent manner
     *
     * @param string $originalTransactionId
     *
     * @return Currency
     */
    public function set_originalTransactionId($originalTransactionId)
    {
        $this->originalTransactionId = $originalTransactionId;
        return $this;
    }

    /**
     * @return string
     */
    public function get_originalTransactionId()
    {
        return $this->originalTransactionId;
    }

}